@@ -31,11 +31,12 @@ MakeChar <- function(x) {
 #'
 #' @examples
 #' data(klassdata)
-#' kommune_names <- apply_klass(x = klassdata$kommune,
-#'                               classification = 131,
-#'                               language = "en",
-#'                               format = FALSE
-#'                               )
+#' kommune_names <- apply_klass(
+#'   x = klassdata$kommune,
+#'   classification = 131,
+#'   language = "en",
+#'   format = FALSE
+#' )
 apply_klass <- function(x,
                         classification,
                         date = NULL,
@@ -45,22 +46,21 @@ apply_klass <- function(x,
                         output_level = NULL,
                         output = "name",
                         format = TRUE) {
-  
   # Check and standardise variables
   classification <- MakeChar(classification)
   if (is.null(x)) {
     stop("The input vector is empty.")
   }
   x <- MakeChar(x)
-  
+
   if (is.null(date)) {
     date <- Sys.Date()
   }
-  
+
   type <- ifelse(is.null(correspond), "vanlig", "kor")
   type <- ifelse(isTRUE(correspond), "change", type)
   type <- ifelse(is.null(variant), type, "variant")
-  
+
   # Fetch classification table
   klass_data <- get_klass(
     classification,
@@ -70,7 +70,7 @@ apply_klass <- function(x,
     language = language,
     output_level = NULL
   )
-  
+
   # Extract correspondence table
   if (type == "kor") {
     cor_table <- get_klass(
@@ -79,7 +79,7 @@ apply_klass <- function(x,
       correspond = correspond,
       language = language
     ) # , output_level = output_level)
-    
+
     new_table <- get_klass(
       classification = correspond,
       date = date,
@@ -96,23 +96,25 @@ apply_klass <- function(x,
       output_level = NULL
     )
   }
-  
+
   # Formattering - only for nace and municipality
   if (format == TRUE & classification %in% c("6", "131")) {
     x_formatted <- formattering(x, classification = classification)
   } else {
     x_formatted <- x
   }
-  
+
   # Check input data for level
   input_level <- levelCheck(x = x_formatted, klass_data = klass_data) # implies all are same level!
-  if (is.null(output_level))
+  if (is.null(output_level)) {
     output_level <- input_level
-  
+  }
+
   if (!all(input_level == output_level) &
-      type %in% c("kor", "change"))
+    type %in% c("kor", "change")) {
     stop("Level changes and time changes/correspondence concurrently is not programmed.")
-  
+  }
+
   # Run level function
   if (!all(input_level == output_level) & is.null(correspond)) {
     x_level <- Levels(
@@ -121,39 +123,42 @@ apply_klass <- function(x,
       klass_data = klass_data
     )
   }
-  
+
   if (all(input_level == output_level)) {
     x_level <- klass_data[klass_data$level == input_level, ]
     x_level[, paste("level", input_level, sep = "")] <- x_level$code
     x_level[, paste("name", input_level, sep = "")] <- x_level$name
   }
-  
-  
+
+
   # run matching
   levelcode <- paste("level", input_level, sep = "")
   if (type %in% c("vanlig", "variant")) {
     m <- match(x_formatted, x_level[, levelcode]) ### sjekk rekkefolge
   }
-  
+
   if (type == "kor") {
     m1 <- match(x_level[, levelcode], cor_table[, "sourceCode"])
     m2 <- match(x_formatted, cor_table[, "sourceCode"])
     m3 <- match(cor_table[, "targetCode"], new_table[, "code"]) ## ?
   }
-  
+
   if (type == "change") {
     m1 <- match(x_formatted, x_level[, levelcode])
     m2 <- match(x_formatted, cor_table$sourceCode)
   }
-  
+
   # Choose format output
   if (type %in% c("vanlig", "variant")) {
-    if (output == "code")
+    if (output == "code") {
       vars <- paste("level", output_level, sep = "")
-    if (output == "name")
+    }
+    if (output == "name") {
       vars <- paste("name", output_level, sep = "")
-    if (output == "both")
+    }
+    if (output == "both") {
       vars <- paste(c("level", "name"), output_level, sep = "")
+    }
     out <- x_level[m, vars]
   }
   if (type == "kor") {
@@ -191,7 +196,7 @@ apply_klass <- function(x,
 
 
 #' @rdname apply_klass
-#' @keywords internal
+#' @param klass Deprecated; use `classification` instead.
 #' @export
 ApplyKlass <- function(x,
                        klass,
